Mesa (master): nir/peephole_select: Rename are_all_move_to_phi and use a switch

Jason Ekstrand jekstrand at kemper.freedesktop.org
Wed Mar 18 00:15:21 UTC 2015


Module: Mesa
Branch: master
Commit: 8cf40ed05dbd3a62ee817e7ebc9409cf327c10ce
URL:    http://cgit.freedesktop.org/mesa/mesa/commit/?id=8cf40ed05dbd3a62ee817e7ebc9409cf327c10ce

Author: Jason Ekstrand <jason.ekstrand at intel.com>
Date:   Mon Mar 16 14:45:54 2015 -0700

nir/peephole_select: Rename are_all_move_to_phi and use a switch

Reviewed-by: Connor Abbott <cwabbott0 at gmail.com>

---

 src/glsl/nir/nir_opt_peephole_select.c |   56 ++++++++++++++++++--------------
 1 file changed, 31 insertions(+), 25 deletions(-)

diff --git a/src/glsl/nir/nir_opt_peephole_select.c b/src/glsl/nir/nir_opt_peephole_select.c
index ab08f28..8371350 100644
--- a/src/glsl/nir/nir_opt_peephole_select.c
+++ b/src/glsl/nir/nir_opt_peephole_select.c
@@ -52,36 +52,41 @@ struct peephole_select_state {
 };
 
 static bool
-are_all_move_to_phi(nir_block *block)
+block_check_for_allowed_instrs(nir_block *block)
 {
    nir_foreach_instr(block, instr) {
-      if (instr->type != nir_instr_type_alu)
-         return false;
+      switch (instr->type) {
+      case nir_instr_type_alu: {
+         /* It must be a move operation */
+         nir_alu_instr *mov = nir_instr_as_alu(instr);
+         if (mov->op != nir_op_fmov && mov->op != nir_op_imov)
+            return false;
 
-      /* It must be a move operation */
-      nir_alu_instr *mov = nir_instr_as_alu(instr);
-      if (mov->op != nir_op_fmov && mov->op != nir_op_imov)
-         return false;
+         /* Can't handle saturate */
+         if (mov->dest.saturate)
+            return false;
 
-      /* Can't handle saturate */
-      if (mov->dest.saturate)
-         return false;
+         /* It must be SSA */
+         if (!mov->dest.dest.is_ssa)
+            return false;
 
-      /* It must be SSA */
-      if (!mov->dest.dest.is_ssa)
-         return false;
+         /* It cannot have any if-uses */
+         if (mov->dest.dest.ssa.if_uses->entries != 0)
+            return false;
 
-      /* It cannot have any if-uses */
-      if (mov->dest.dest.ssa.if_uses->entries != 0)
-         return false;
+         /* The only uses of this definition must be phi's in the successor */
+         struct set_entry *entry;
+         set_foreach(mov->dest.dest.ssa.uses, entry) {
+            const nir_instr *dest_instr = entry->key;
+            if (dest_instr->type != nir_instr_type_phi ||
+                dest_instr->block != block->successors[0])
+               return false;
+         }
+         break;
+      }
 
-      /* The only uses of this definition must be phi's in the successor */
-      struct set_entry *entry;
-      set_foreach(mov->dest.dest.ssa.uses, entry) {
-         const nir_instr *dest_instr = entry->key;
-         if (dest_instr->type != nir_instr_type_phi ||
-             dest_instr->block != block->successors[0])
-            return false;
+      default:
+         return false;
       }
    }
 
@@ -119,8 +124,9 @@ nir_opt_peephole_select_block(nir_block *block, void *void_state)
    nir_block *then_block = nir_cf_node_as_block(then_node);
    nir_block *else_block = nir_cf_node_as_block(else_node);
 
-   /* ... and those blocks must only contain move-to-phi. */
-   if (!are_all_move_to_phi(then_block) || !are_all_move_to_phi(else_block))
+   /* ... and those blocks must only contain "allowed" instructions. */
+   if (!block_check_for_allowed_instrs(then_block) ||
+       !block_check_for_allowed_instrs(else_block))
       return true;
 
    /* At this point, we know that the previous CFG node is an if-then




More information about the mesa-commit mailing list